@@ -1,6 +1,6 @@
 test_that("CSV works", {
-  sc <- test_spark_connect()
-  tbl_mtcars <- test_table_mtcars()
+  sc <- use_test_spark_connect()
+  tbl_mtcars <- use_test_table_mtcars()
   file_name <- tempfile()
   expect_silent(spark_write_csv(tbl_mtcars, file_name))
   expect_snapshot(
@@ -9,8 +9,8 @@ test_that("CSV works", {
 })
 
 test_that("Parquet works", {
-  sc <- test_spark_connect()
-  tbl_mtcars <- test_table_mtcars()
+  sc <- use_test_spark_connect()
+  tbl_mtcars <- use_test_table_mtcars()
   file_name <- tempfile()
   expect_silent(spark_write_parquet(tbl_mtcars, file_name))
   expect_snapshot(
@@ -19,8 +19,8 @@ test_that("Parquet works", {
 })
 
 test_that("ORC works", {
-  sc <- test_spark_connect()
-  tbl_mtcars <- test_table_mtcars()
+  sc <- use_test_spark_connect()
+  tbl_mtcars <- use_test_table_mtcars()
   file_name <- tempfile()
   expect_silent(spark_write_orc(tbl_mtcars, file_name))
   expect_snapshot(
@@ -29,8 +29,8 @@ test_that("ORC works", {
 })
 
 test_that("JSON works", {
-  sc <- test_spark_connect()
-  tbl_mtcars <- test_table_mtcars()
+  sc <- use_test_spark_connect()
+  tbl_mtcars <- use_test_table_mtcars()
   file_name <- tempfile()
   expect_silent(spark_write_json(tbl_mtcars, file_name))
   expect_snapshot(
